/****************************************************************************
 *
 * program
 *
 * Description
 *
 * Copyright (C) 2007 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/

#ifndef BPEL_ACTIVITYVISITOR_HH
#define BPEL_ACTIVITYVISITOR_HH

// Forward declarations
class SequenceActivity;
class InvokeActivity;
class FlowActivity;
class DummyActivity;
class WhileActivity;
class RepeatActivity;
class BPELModel;

/**
 * This class is used to visit a BPEL activity structure, using the
 * "visitor pattern"
 */
class ActivityVisitor {
protected:
    ActivityVisitor( ) { };
public:
    virtual ~ActivityVisitor( ) { };

    /**
     * Visits a Sequence
     *
     * @param a the Sequence to visit
     */
    virtual void visit_sequence( SequenceActivity* a ) = 0;

    /**
     * Visits an Invoke 
     *
     * @param a the Invoke activity to visit
     */
    virtual void visit_invoke( InvokeActivity* a ) = 0;

    /**
     * Visits a Flow
     *
     * @param a the Flow activity to visit
     */
    virtual void visit_flow( FlowActivity* a ) = 0;

    /**
     * Visits a Dummy Activity
     *
     * @param a the Dummy activity to visit
     */
    virtual void visit_dummy( DummyActivity* a ) = 0;

    /**
     * Visits a While Activity
     *
     * @param a the While activity to visit
     */
    virtual void visit_while( WhileActivity* a ) = 0;

    /**
     * Visits a repeatUntil Activity
     *
     * @param a the repeatUntil activity to visit
     */
    virtual void visit_repeat( RepeatActivity* a ) = 0;

    /**
     * Visits a BPEL model
     */
    virtual void visit_bpel_model( BPELModel* m ) = 0;
};

#endif
