/****************************************************************************
 *
 * program
 *
 * Description
 *
 * Copyright (C) 2007 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/

#ifndef BPEL_BPELMODEL_HH
#define BPEL_BPELMODEL_HH

#include <string>
#include <map>
#include "Visitable.hh"

class Activity;
class WSDLOperation;

class BPELModel : public Visitable {
public:
    typedef enum { open_workload, closed_workload } BPEL_Type;

protected:
    const std::string m_name;
    Activity* m_root_activity;
    std::map< std::string, WSDLOperation* > m_operations;
    BPEL_Type m_type;
    int m_population;
    double m_think_time;
    double m_arrival_rate;

public:

    /**
     * Creates an empty BPEL model with a given name.
     *
     * @param name the name of the model.
     */ 
    BPELModel( const std::string& name );

    ~BPELModel( );

    /**
     * Used by the visitor
     */
    void accept( ActivityVisitor* v );

    /**
     * Sets the root activity.
     */ 
    void set_root_activity( Activity* a ) { m_root_activity = a; };

    /**
     * Adds a new operation. Aborts if an operation with the same name
     * has already been added. Ownership is transferred to this
     * object: the caller must not free the passed object.
     */ 
    void add_operation( WSDLOperation* op );

    /**
     * Returns the root activity.
     */
    Activity* get_root_activity( void ) { return m_root_activity; };

    /**
     * Gets an operation given its (unique) name
     *
     * @param name the name of the operation
     *
     * @return the operation with the given name, or 0 if none is found
     */
    WSDLOperation* get_operation_by_name( const std::string& name );

    void set_type( BPEL_Type t ) { m_type = t; };

    void set_population( int n ) { m_population = n; };

    void set_think_time( double Z ) { m_think_time = Z; };

    void set_arrival_rate( double lambda ) { m_arrival_rate = lambda; };

    BPEL_Type get_type( void ) const { return m_type; };

    int get_population( void ) const { return m_population; };

    double get_think_time( void ) const { return m_think_time; };

    double get_arrival_rate( void ) const { return m_arrival_rate; };
};

#endif
