/****************************************************************************
 *
 * Utils.hh
 *
 * This file is part of bpel2qnbound
 *
 * Copyright (C) 2007 Moreno Marzolla
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 ****************************************************************************/
#ifndef BPEL_UTILS_HH
#define BPEL_UTILS_HH

extern "C" {
#include <libxml/tree.h>
}
#include <string>

/**
 * This class returns an XML attribute as an integer, double or string value.
 */
class BPELAttribute {
    const xmlChar* m_value;
public:
    /**
     * Initializes the BPELAttribute object.
     *
     * @param n the XML node from which the attribute should be obtained.
     *
     * @param name the name of the XML attribute to read. If the
     * attribute is not present in the XML node n, then the
     * as_string() method will return the empty string, while the
     * other methods will likely crash the program.
     */
    BPELAttribute( xmlNodePtr n, const char* name );

    ~BPELAttribute( ) { };

    /**
     * Returns the integer representation of the attribute. 
     *
     * @return the integer representatin of the attribute; will likely
     * crash if the attribute is not present in the given XML node.
     */
    int as_int( void ) const;

    /**
     * Returns the double representation of the attribute. 
     *
     * @return the double representatin of the attribute; will likely
     * crash if the attribute is not present in the given XML node.
     */
    double as_double( void ) const;

    /**
     * Returns the string representation of the attribute. 
     *
     * @return the string representatin of the attribute; returns the
     * empty string if the attribute is not present in the given XML
     * node.
     */
    std::string as_string( void ) const;
};

#endif
